using System;
using System.Net;

namespace cloud.insecurity.http
{
    public sealed class DefaultHttpResponse : IHttpResponse
    {
        private readonly HttpListenerContext Context;
        
        public WebHeaderCollection Headers = new WebHeaderCollection()
        {
            {"Server", "insecurity"}, 
        };
        public DefaultHttpResponse(HttpListenerContext context)
        {
            Context = context;
            Context.Response.Headers = Headers;
        }
        public void Dispose()
        {
            Context.Response.OutputStream.Dispose();
        }

        public IHttpResponse SendResponse()
        {
            Context.Response.OutputStream.Close();
            return this;
        }

        public IHttpResponse NotFound()
        {
            Context.Response.StatusCode = (int) IHttpResponse.ResponseCodes.NotFound;
            return this;
        }

        public IHttpResponse InternalServerError()
        {
            Context.Response.StatusCode = (int) IHttpResponse.ResponseCodes.InternalServerError;
            return this;
        }

        public IHttpResponse NotImplemented()
        {
            Context.Response.StatusCode = (int) IHttpResponse.ResponseCodes.NotImplemented;
            return this;
        }

        public IHttpResponse Ok()
        {
            Context.Response.StatusCode = (int) IHttpResponse.ResponseCodes.Ok;
            return this;
        }

        public static IHttpResponse New(HttpListenerContext context)
        {
            return new DefaultHttpResponse(context);
        }
    }
}